@@ -1,9 +1,9 @@
 # -*- coding: utf-8 -*-
 from __future__ import absolute_import, unicode_literals
 from google.appengine.ext.ndb.model import IntegerProperty, StringProperty, DateTimeProperty, DateProperty, \
-    FloatProperty, TextProperty, BooleanProperty
+    FloatProperty, TextProperty, BooleanProperty, KeyProperty
 from gaeforms.base import IntegerField, Form, _FormMetaclass, DecimalField, StringField, DateField, DateTimeField, \
-    FloatField, EmailField, BooleanField
+    FloatField, EmailField, BooleanField, KeyField
 from gaeforms.ndb.property import IntegerBounded, SimpleDecimal, SimpleCurrency, FloatBounded, Email
 
 _property_to_field_dct = {}
@@ -25,6 +25,7 @@ registry(FloatProperty, FloatField)
 registry(FloatBounded, FloatField)
 registry(Email, EmailField)
 registry(BooleanProperty, BooleanField)
+registry(KeyProperty, KeyField)
 
 
 class NotRegisteredProperty(Exception):
